function Ivals = fExtract2CellArr_2(dat,Weight,Centre,aMin,aMax,s4opt)
%--------------------------------------------------------------------
% Ivals - Cell array containing which contains the 
%  intensities at points with similar s-values. Ivals{n,1} is a 
%  vector of intensities for the n-th s-value. Ivals{n,2} is an 
%  Nx2 matrix with the corresponding positions for each point.
% dat - image data
% Weight - Mask or weight matrix
% Centre - [yCentre xCentre]
% aMin - minimum angle
% aMax - maximum angle
% s4opt - true if you wish to multiply by s^4, otherwise false
%----------------------------------------------------------------
% SAH 20.Sep.2010
%------------------
global sMin;
global sMax;
global sDelta;
global sRange;
global nData;
global xPixel;
global yPixel;
global eWavL;
global rCamera;
nCount  = zeros(1,nData);
s = 0.0;
min = sMin-0.5*sDelta;
max = sMax+0.5*sDelta;
% create a Cell Array of useful points:
for i=1:1024
  for j=1:1024
    if (Weight(i,j))
      dRX = xPixel*(j-Centre(2));
      dRY =-yPixel*(i-Centre(1));
      if dRY ~= 0
        angle = atan(dRX/dRY);
      else
        angle = 0.5*pi;
      end
      if (dRY < 0.0)
        angle = angle + pi;
      elseif (dRX < 0.0)
        angle = angle + 2*pi;
      end
      if ((aMin < angle) && (angle < aMax))
        dR = sqrt(dRX^2 + dRY^2);
        theta = atan(dR/rCamera);
        s = 4*pi*sin(0.5*theta)/eWavL;
        if ((min < s) && (s < max))
          nS = round(1 + (s - sMin)/sDelta);
          nCount(nS) = nCount(nS) + 1;
          indx = nCount(nS);
          if s4opt
            Ivals{nS,1}(indx) = (s^4)*dat(i,j)/(cos(theta)^3);
          else
            Ivals{nS,1}(indx) = dat(i,j)/(cos(theta)^3);
          end
            Ivals{nS,2}(indx,:) = [i,j];
        end
      end
     end
  end
end
disp('data compiled in Cell Array');
return
