c     Model for tetrakis(bromodimethylsilyl)methane - multiconformer

	SUBROUTINE coord(nAtom,nIPar,nDist,x,y,z,par,uVal,rMult,ampDist)
	IMPLICIT REAL*8(a-h,o-z)

c	Dummy arrays
	DIMENSION x(nAtom),y(nAtom),z(nAtom)
	DIMENSION xa(nAtom),ya(nAtom),za(nAtom)
	DIMENSION par(nIPar),pp(50)
	DIMENSION uVal(nDist),rMult(nDist),ampDist(nDist)

c	Local arrays
	CHARACTER*2 attype(nAtom),attypea(nAtom)
	integer qq(nAtom)
	DIMENSION p(100)

c	Data statements
	attype = (/'C','H','H','H','C','H','H','H','Si','Br','C','C','H',
     +'H','H','C','H','H','H','Si','Br','C','H','H','H','C','H','H','H',
     +'Si','Br','C','H','H','H','C','H','H','H','Si','Br','C','H','H',
     +'H','C','H','H','H','Si','Br','C','C','H','H','H','C','H','H','H',
     +'Si','Br','C','H','H','H','C','H','H','H','Si','Br','C','H','H',
     +'H','C','H','H','H','Si','Br'/)

      qq=(/12,38,36,37,13,41,39,40,2,14,1,8,25,26,24,9,27,28,29,3,16,
     +11,34,35,33,10,30,31,32,4,15,7,21,22,23,6,19,20,18,5,17,53,
     +79,77,78,54,82,80,81,43,55,42,49,66,67,65,50,68,69,70,44,57,52,
     +75,76,74,51,71,72,73,45,56,48,62,63,64,47,60,61,59,46,58/)

c       qq=(/1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,
c     +22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,
c     +43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,
c     +64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82/)
c    
	pi=dacos(-1.0d0)
      rad=pi/180.0d0

c	Parameters for use in model

	rCSi1=par(1)+par(2)/3		! methyl carbon to silicon
	rCSi2=par(1)-2*par(2)/3				! central carbon to silicon
	rSiBr=par(3)			! silicon bromine distance
	rCH=par(4)				! carbon hydrogen distance
	aSiCH=par(5)*rad		! silicon methyl carbon to hydrogen angle
	aCSiC1=par(6)*rad		! central c si to methyl c angle
	aCSiC2=par(7)*rad		! methyl c si to methyl c angle
	aCSiBr1=par(8)*rad		! central c si Br
	aCSiBr2=par(9)*rad		! methyl c si Br
	aSiCSi=par(10)*rad		! si central c si
	dH1CSiBr=par(11)*rad	! end on view(SiC2H6Br), d left methyl H to Br
	dH2CSiBr=par(12)*rad	! end on view(SiC2H6Br), d right methyl H to Br
	dBrSiCSi1=par(13)*rad	! Conf 1
	dBrSiCSi2=par(14)*rad	! Conf 1
	dBrSiCSi3=par(15)*rad	! Conf 1
	dBrSiCSi4=par(16)*rad	! Conf 1
	dBrSiCSi5=par(17)*rad	! Conf 2
	dBrSiCSi6=par(18)*rad	! Conf 2

c	******************************
c	Start of model
c	First conformer Conformer (12A)
c	******************************
c     Start of branch 1
      do i=1,41
	X(i)=0.0
	Y(i)=0.0
	Z(i)=0.0
	enddo
     
c     Define first SiMe2Br group
c     Set C(1) at the origin
      X(1)=0.0
      Y(1)=0.0
      Z(1)=0.0

c     Set H(2) in x-y plane
      X(2)=rCH*dcos(aSiCH)
      Y(2)=rCH*dsin(aSiCH)
      Z(2)=0.0
      
c     generate Me group around C(1)
      Do i=1,2
      X(2+i)=X(2)
      Y(2+i)=Y(2)*dcos(120.*i*rad)-Z(2)*dsin(120.*i*rad)
      Z(2+i)=Y(2)*dsin(120.*i*rad)+Z(2)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(4+i)=X(i)
      Y(4+i)=Y(i)
      Z(4+i)=Z(i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=1,4
      A=Y(i)
      Y(i)=A*dcos(dH1CSiBr)-Z(i)*dsin(dH1CSiBr)
      Z(i)=A*dsin(dH1CSiBr)+Z(i)*dcos(dH1CSiBr)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=5,8
      A=Y(i)
      Y(i)=A*dcos(dH2CSiBr)-Z(i)*dsin(dH2CSiBr)
      Z(i)=A*dsin(dH2CSiBr)+Z(i)*dcos(dH2CSiBr)   
      enddo

c     Place Si(9) to origin
      X(9)=0.0
      Y(9)=0.0
      Z(9)=0.0
      
c     Move 1st Me group away from Si(9)
      Do i=1,4
      X(i)=X(i)-rCSi1-0.003
      enddo

c     Move 2nd Me group away from Si(9)
      Do i=5,8
      X(i)=X(i)-rCSi1+0.001
      enddo

c     Set Br(10) in x-y plane
      X(10)=(rSiBr+0.01)*dcos(aCSiBr1-0.96*rad)
      Y(10)=(rSiBr+0.01)*dsin(aCSiBr1-0.96*rad)
      Z(10)=0.0
  
c     Bend methyl group 1 into position
      Do i=1,4
      A=X(i)
      X(i)=A*dcos(aCSiC1+1.32*rad+pi)-Y(i)*dsin(aCSiC1+1.32*rad+pi)
      Y(i)=A*dsin(aCSiC1+1.32*rad+pi)+Y(i)*dcos(aCSiC1+1.32*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=5,8
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.60*rad+pi)-Y(i)*dsin(aCSiC1-0.60*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.60*rad+pi)+Y(i)*dcos(aCSiC1-0.60*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(9)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d1)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d2)

c     Move methyl groups about x axis using dihedrals generated above
      do i=1,4
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=5,8
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo

c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=1,10
      X(i)=X(i)-rCSi2-0.001
      enddo

c	Create dihedral angle between Br of branch 1 and branch 2.
	Do i=1,10
	A=Y(i)
	Y(i)=A*dcos(dBrSiCSi1)-Z(i)*dsin(dBrSiCSi1)
	Z(i)=-(A*dsin(dBrSiCSi1)+Z(i)*dcos(dBrSiCSi1))
	enddo



c     Start of branch 2
c     Define first SiMe2Br group
c     Set C(12) at the origin
      X(12)=0.0
      Y(12)=0.0
      Z(12)=0.0

c     Set H(13) in x-y plane
      X(13)=rCH*dcos(aSiCH)
      Y(13)=rCH*dsin(aSiCH)
      Z(13)=0.0
      
c     generate Me group around C(12)
      Do i=1,2
      X(13+i)=X(13)
      Y(13+i)=Y(13)*dcos(120.*i*rad)-Z(13)*dsin(120.*i*rad)
      Z(13+i)=Y(13)*dsin(120.*i*rad)+Z(13)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(15+i)=X(11+i)
      Y(15+i)=Y(11+i)
      Z(15+i)=Z(11+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=1,4
      A=Y(11+i)
      Y(11+i)=A*dcos(dH1CSiBr)-Z(11+i)*dsin(dH1CSiBr)
      Z(11+i)=A*dsin(dH1CSiBr)+Z(11+i)*dcos(dH1CSiBr)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=16,19
      A=Y(i)
      Y(i)=A*dcos(dH2CSiBr)-Z(i)*dsin(dH2CSiBr)
      Z(i)=A*dsin(dH2CSiBr)+Z(i)*dcos(dH2CSiBr)   
      enddo

c     Place Si(20) to origin
      X(20)=0.0
      Y(20)=0.0
      Z(20)=0.0
      
c     Move 1st Me group away from Si(20)
      Do i=12,15
      X(i)=X(i)-rCSi1+0.002
      enddo

c     Move 2nd Me group away from Si(20)
      Do i=16,19
      X(i)=X(i)-rCSi1-0.001
      enddo

c     Set Br(21) in x-y plane
      X(21)=(rSiBr+0.006)*dcos(aCSiBr1-0.77*rad)
      Y(21)=(rSiBr+0.006)*dsin(aCSiBr1-0.77*rad)
      Z(21)=0.0
  
c     Bend methyl group 1 into position
      Do i=12,15
      A=X(i)
      X(i)=A*dcos(aCSiC1+1.39*rad+pi)-Y(i)*dsin(aCSiC1+1.39*rad+pi)
      Y(i)=A*dsin(aCSiC1+1.39*rad+pi)+Y(i)*dcos(aCSiC1+1.39*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=16,19
      A=X(i)
      X(i)=A*dcos(aCSiC1+0.20*rad+pi)-Y(i)*dsin(aCSiC1+0.20*rad+pi)
      Y(i)=A*dsin(aCSiC1+0.20*rad+pi)+Y(i)*dcos(aCSiC1+0.20*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(20)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d1)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d2)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=12,15
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=16,19
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo

c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=12,21
      X(i)=X(i)-rCSi2-0.00
      enddo

c	Create dihedral angle between Br of branch 2 and branch 1.
	Do i=12,21
	A=Y(i)
	Y(i)=-(A*dcos(dBrSiCSi2)-Z(i)*dsin(dBrSiCSi2))
	Z(i)=A*dsin(dBrSiCSi2)+Z(i)*dcos(dBrSiCSi2)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=12,21
	A=X(i)
      X(i)=A*dcos(-aSiCSi+0.03)-Y(i)*dsin(-aSiCSi+0.03)
      Y(i)=A*dsin(-aSiCSi+0.03)+Y(i)*dcos(-aSiCSi+0.03)
	enddo



c     Start of Branch 3
c	Define first SiMe2Br group
c	Set C(22) at the origin
      X(22)=0.0
      Y(22)=0.0
      Z(22)=0.0

c     Set H(23) in x-y plane
      X(23)=rCH*dcos(aSiCH)
      Y(23)=rCH*dsin(aSiCH)
      Z(23)=0.0
      
c     generate Me group around C(22)
      Do i=1,2
      X(23+i)=X(23)
      Y(23+i)=Y(23)*dcos(120.*i*rad)-Z(23)*dsin(120.*i*rad)
      Z(23+i)=Y(23)*dsin(120.*i*rad)+Z(23)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(25+i)=X(21+i)
      Y(25+i)=Y(21+i)
      Z(25+i)=Z(21+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=22,25
      A=Y(i)
      Y(i)=A*dcos(dH1CSiBr)-Z(i)*dsin(dH1CSiBr)
      Z(i)=A*dsin(dH1CSiBr)+Z(i)*dcos(dH1CSiBr)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=26,29
      A=Y(i)
      Y(i)=A*dcos(dH2CSiBr)-Z(i)*dsin(dH2CSiBr)
      Z(i)=A*dsin(dH2CSiBr)+Z(i)*dcos(dH2CSiBr)   
      enddo

c     Place Si(30) to origin
      X(30)=0.0
      Y(30)=0.0
      Z(30)=0.0
      
c     Move 1st Me group away from Si(30)
      Do i=22,25
      X(i)=X(i)-rCSi1+0.001
      enddo

c     Move 2nd Me group away from Si(30)
      Do i=26,29
      X(i)=X(i)-rCSi1+0.001
      enddo

c     Set Br(31) in x-y plane
      X(31)=(rSiBr-0.017)*dcos(aCSiBr1+1.00*rad)
      Y(31)=(rSiBr-0.017)*dsin(aCSiBr1+1.00*rad)
      Z(31)=0.0
 
c     Bend methyl group 1 into position
      Do i=22,25
      A=X(i)
      X(i)=A*dcos(aCSiC1-1.04*rad+pi)-Y(i)*dsin(aCSiC1-1.04*rad+pi)
      Y(i)=A*dsin(aCSiC1-1.04*rad+pi)+Y(i)*dcos(aCSiC1-1.04*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=26,29
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.93*rad+pi)-Y(i)*dsin(aCSiC1-0.93*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.93*rad+pi)+Y(i)*dcos(aCSiC1-0.93*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(30)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d1)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d2)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=22,25
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=26,29
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo


c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=22,31
      X(i)=X(i)-rCSi2-0.004
      enddo

c	Create dihedral angle between Br of branch 3 and branch 1.
	Do i=22,31
	A=Y(i)
	Y(i)=-(A*dcos(dBrSiCSi3)-Z(i)*dsin(dBrSiCSi3))
	Z(i)=A*dsin(dBrSiCSi3)+Z(i)*dcos(dBrSiCSi3)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=22,31
	A=X(i)
      X(i)=A*dcos(-aSiCSi-0.88*rad)-Y(i)*dsin(-aSiCSi-0.88*rad)
      Y(i)=A*dsin(-aSiCSi-0.88*rad)+Y(i)*dcos(-aSiCSi-0.88*rad)
	enddo


c     Start of Branch 4
c     Define first SiMe2Br group
c     Set C(32) at the origin
      X(32)=0.0
      Y(32)=0.0
      Z(32)=0.0

c     Set H(33) in x-y plane
      X(33)=rCH*dcos(aSiCH)
      Y(33)=rCH*dsin(aSiCH)
      Z(33)=0.0
      
c     generate Me group around C(32)
      Do i=1,2
      X(33+i)=X(33)
      Y(33+i)=Y(33)*dcos(120.*i*rad)-Z(33)*dsin(120.*i*rad)
      Z(33+i)=Y(33)*dsin(120.*i*rad)+Z(33)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(35+i)=X(31+i)
      Y(35+i)=Y(31+i)
      Z(35+i)=Z(31+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=32,35
      A=Y(i)
      Y(i)=A*dcos(dH1CSiBr)-Z(i)*dsin(dH1CSiBr)
      Z(i)=A*dsin(dH1CSiBr)+Z(i)*dcos(dH1CSiBr)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=36,39
      A=Y(i)
      Y(i)=A*dcos(dH2CSiBr)-Z(i)*dsin(dH2CSiBr)
      Z(i)=A*dsin(dH2CSiBr)+Z(i)*dcos(dH2CSiBr)   
      enddo

c     Place Si(40) to origin
      X(40)=0.0
      Y(40)=0.0
      Z(40)=0.0
      
c     Move 1st Me group away from Si(40)
      Do i=32,35
      X(i)=X(i)-rCSi1+0.003
      enddo

c     Move 2nd Me group away from Si(40)
      Do i=36,39
      X(i)=X(i)-rCSi1-0.003
      enddo
	
c     Set Br(41) in x-y plane
      X(41)=(rSiBr+0.000)*dcos(aCSiBr1+0.74*rad)
      Y(41)=(rSiBr+0.000)*dsin(aCSiBr1+0.74*rad)
      Z(41)=0.0
  
c     Bend methyl group 1 into position
      Do i=32,35
      A=X(i)
      X(i)=A*dcos(aCSiC1+1.01*rad+pi)-Y(i)*dsin(aCSiC1+1.01*rad+pi)
      Y(i)=A*dsin(aCSiC1+1.01*rad+pi)+Y(i)*dcos(aCSiC1+1.01*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=36,39
      A=X(i)
      X(i)=A*dcos(aCSiC1-1.34*rad+pi)-Y(i)*dsin(aCSiC1-1.34*rad+pi)
      Y(i)=A*dsin(aCSiC1-1.34*rad+pi)+Y(i)*dcos(aCSiC1-1.34*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(30)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d1)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d2)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=32,35
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=36,39
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo

c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=32,41
      X(i)=X(i)-rCSi2+0.005
      enddo

c	Create dihedral angle between Br of branch 4 and branch 1.
	Do i=32,41
	A=Y(i)
	Y(i)=-(A*dcos(dBrSiCSi4)-Z(i)*dsin(dBrSiCSi4))
	Z(i)=A*dsin(dBrSiCSi4)+Z(i)*dcos(dBrSiCSi4)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=32,41
	A=X(i)
      X(i)=A*dcos(-aSiCSi+0.69*rad)-Y(i)*dsin(-aSiCSi+0.69*rad)
      Y(i)=A*dsin(-aSiCSi+0.69*rad)+Y(i)*dcos(-aSiCSi+0.69*rad)
	enddo


c     Put 3rd and 4th branch in position by rotation around C(11)
c     Generate dihedral angles to move branches (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aSiCSi,aSiCSi,aSiCSi,d3)
      call DihedralFromBeta(rCSi1,rCSi1,aSiCSi,aSiCSi,aSiCSi,d4)

c     Move branches about x axis using dihedrals generated above
      do i=22,31
      A=Y(i)
      Y(i)=A*dcos(-d3)-Z(i)*dsin(-d3)
      Z(i)=A*dsin(-d3)+Z(i)*dcos(-d3)
      enddo

      do i=32,41
      A=Y(i)
      Y(i)=A*dcos(d4)-Z(i)*dsin(d4)
      Z(i)=A*dsin(d4)+Z(i)*dcos(d4)
      enddo

c*************************************************************
	do i=1,41
	X(i)=X(i)+10
	enddo
c*************************************************************




c	*****************************************************************************************
c	Start of Conformer 2 (9A) 
c	******************************************************************************************


c     Set C(42) at the origin
      X(42)=0.0
      Y(42)=0.0
      Z(42)=0.0

c     Set H(43) in x-y plane
      X(43)=rCH*dcos(aSiCH)
      Y(43)=rCH*dsin(aSiCH)
      Z(43)=0.0
      
c     generate Me group around C(42)
      Do i=1,2
      X(43+i)=X(43)
      Y(43+i)=Y(43)*dcos(120.*i*rad)-Z(43)*dsin(120.*i*rad)
      Z(43+i)=Y(43)*dsin(120.*i*rad)+Z(43)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(45+i)=X(41+i)
	Y(45+i)=Y(41+i)
      Z(45+i)=Z(41+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=42,45
      A=Y(i)
      Y(i)=A*dcos(dH1CSiBr)-Z(i)*dsin(dH1CSiBr)
      Z(i)=A*dsin(dH1CSiBr)+Z(i)*dcos(dH1CSiBr)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=46,49
      A=Y(i)
      Y(i)=A*dcos(dH2CSiBr)-Z(i)*dsin(dH2CSiBr)
      Z(i)=A*dsin(dH2CSiBr)+Z(i)*dcos(dH2CSiBr)   
      enddo


c     Place Si(50) to origin
      X(50)=0.0
      Y(50)=0.0
      Z(50)=0.0
      
c     Move 1st Me group away from Si(50)
      Do i=42,45
      X(i)=X(i)-rCSi1-0.006
      enddo

c     Move 2nd Me group away from Si(50)
      Do i=46,49
      X(i)=X(i)-rCSi1+0.003
      enddo

c     Set Br(51) in x-y plane
      X(51)=(rSiBr-0.010)*dcos(aCSiBr1+0.82*rad)
      Y(51)=(rSiBr-0.010)*dsin(aCSiBr1+0.82*rad)
      Z(51)=0.0
  
c     Bend methyl group 1 into position
      Do i=42,45
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.67*rad+pi)-Y(i)*dsin(aCSiC1-0.67*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.67*rad+pi)+Y(i)*dcos(aCSiC1-0.67*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=46,49
      A=X(i)
      X(i)=A*dcos(aCSiC1+0.75*rad+pi)-Y(i)*dsin(aCSiC1+0.75*rad+pi)
      Y(i)=A*dsin(aCSiC1+0.75*rad+pi)+Y(i)*dcos(aCSiC1+0.75*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(50)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d1)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d2)

c     Move methyl groups about x axis using dihedrals generated above
      do i=42,45
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=46,49
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo

c     Move origin to C(52)
      X(52)=0.0
      Y(52)=0.0
      Z(52)=0.0

      Do i=42,51
      X(i)=X(i)-rCSi2-0.006
      enddo

c	Create dihedral angle between Br of branch 1 and branch 3.
	Do i=42,51
	A=Y(i)
	Y(i)=A*dcos(dBrSiCSi5)-Z(i)*dsin(dBrSiCSi5)
	Z(i)=-(A*dsin(dBrSiCSi5)+Z(i)*dcos(dBrSiCSi5))
	enddo





c     Start of Branch 3
c	Define first SiMe2Br group
c	Set C(63) at the origin
      X(63)=0.0
      Y(63)=0.0
      Z(63)=0.0

c     Set H(64) in x-y plane
      X(64)=rCH*dcos(aSiCH)
      Y(64)=rCH*dsin(aSiCH)
      Z(64)=0.0
      
c     generate Me group around C(63)
      Do i=1,2
      X(64+i)=X(64)
      Y(64+i)=Y(64)*dcos(120.*i*rad)-Z(64)*dsin(120.*i*rad)
      Z(64+i)=Y(64)*dsin(120.*i*rad)+Z(64)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=42,45
      X(25+i)=X(21+i)
	Y(25+i)=Y(21+i)
      Z(25+i)=Z(21+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=63,66
      A=Y(i)
      Y(i)=A*dcos(dH1CSiBr)-Z(i)*dsin(dH1CSiBr)
      Z(i)=A*dsin(dH1CSiBr)+Z(i)*dcos(dH1CSiBr)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=67,70
      A=Y(i)
      Y(i)=A*dcos(dH2CSiBr)-Z(i)*dsin(dH2CSiBr)
      Z(i)=A*dsin(dH2CSiBr)+Z(i)*dcos(dH2CSiBr)   
      enddo

c     Place Si(71) to origin
      X(71)=0.0
      Y(71)=0.0
      Z(71)=0.0
      
c     Move 1st Me group away from Si(71)
      Do i=63,66
      X(i)=X(i)-rCSi1-0.000
      enddo

c     Move 2nd Me group away from Si(71)
      Do i=67,70
      X(i)=X(i)-rCSi1-0.000
      enddo

c     Set Br(72) in x-y plane
      X(72)=(rSiBr+0.00)*dcos(aCSiBr1+0.61*rad)
      Y(72)=(rSiBr+0.00)*dsin(aCSiBr1+0.61*rad)
      Z(72)=0.0
 
c     Bend methyl group 1 into position
      Do i=63,66
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.21*rad+pi)-Y(i)*dsin(aCSiC1-0.21*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.21*rad+pi)+Y(i)*dcos(aCSiC1-0.21*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=67,70
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.75*rad+pi)-Y(i)*dsin(aCSiC1-0.75*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.75*rad+pi)+Y(i)*dcos(aCSiC1-0.75*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(71)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d1)
      call DihedralFromBeta(rCSi1,rCSi1,aCSiBr2,aCSiBr1,aCSiC1,d2)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=63,66
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=67,70
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo


c     Move origin to C(52)
      X(52)=0.0
      Y(52)=0.0
      Z(52)=0.0

      Do i=63,72
      X(i)=X(i)-rCSi2+0.005
      enddo

c	Create dihedral angle between Br of branch 3 and branch 1.
	Do i=63,72
	A=Y(i)
	Y(i)=-(A*dcos(dBrSiCSi6)-Z(i)*dsin(dBrSiCSi6))
	Z(i)=A*dsin(dBrSiCSi6)+Z(i)*dcos(dBrSiCSi6)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=63,72
	A=X(i)
      X(i)=A*dcos(-aSiCSi+2.72*rad)-Y(i)*dsin(-aSiCSi+2.72*rad)
      Y(i)=A*dsin(-aSiCSi+2.72*rad)+Y(i)*dcos(-aSiCSi+2.72*rad)
	enddo

c	rotate around z by (angle between branch 1 and 3)/2
	do i=42,82
	A=X(i)
	X(i)=A*dcos((aSiCSi-2.72*rad)/2)-Y(i)*dsin((aSiCSi-2.72*rad)/2)
	Y(i)=A*dsin((aSiCSi-2.72*rad)/2)+Y(i)*dcos((aSiCSi-2.72*rad)/2)
	enddo

c	Place atoms 53-62 on 42-51 
	do i=53,62
	X(i)=X(i-11)
	Y(i)=Y(i-11)
	Z(i)=Z(i-11)
	enddo

c	 73-82 on 63-72
	Do i=73,82
	X(i)=X(i-10)
	Y(i)=Y(i-10)
	Z(i)=Z(i-10)
	enddo

c	Rotate branch 2 and 4 about y axis by pi
	do i=53,62
	A=X(i)
	X(i)=A*dcos(pi)+Z(i)*dsin(pi)
	Z(i)=-A*dsin(pi)+Z(i)*dcos(pi)
	enddo

	do i=73,82
	A=X(i)
	X(i)=A*dcos(pi)+Z(i)*dsin(pi)
	Z(i)=-A*dsin(pi)+Z(i)*dcos(pi)
	enddo


c	Rotate about x-axis by (dSiCXSi)
	do i=53,62
	A=Y(i)
	Y(i)=A*dcos(-pi/2)-Z(i)*dsin(-pi/2)
	Z(i)=A*dsin(-pi/2)+Z(i)*dcos(-pi/2)
	enddo

c	Rotate about x-axis by (dSiCXSi)
	do i=73,82
	A=Y(i)
	Y(i)=A*dcos(-pi/2)-Z(i)*dsin(-pi/2)
	Z(i)=A*dsin(-pi/2)+Z(i)*dcos(-pi/2)
	enddo




c	assumptions made in the model
c	for C2 conformer use pi around y and pi/2 around the x to orient in the other two arms. This
c	is assumed correct as it does not vary by much for any of the conformer for which it is used.
c
c
c
c
c
c
c
c
c

c	Make numbering same as ab initio
	Do i=1,nAtom-1
	XA(qq(i))=X(i)
	YA(qq(i))=Y(i)
	ZA(qq(i))=Z(i)
	attypea(qq(i))=attype(i)
	enddo

	Do i=1,nAtom-1
	X(i)=XA(i)
	Y(i)=YA(i)
	Z(i)=ZA(i)
	attype(i)=attypea(i)
	enddo

c     Write the co-ordinates
	CALL writeXYZ('coord.xyz',nAtom,x,y,z,attype)

	RETURN
	END

c     Subroutine writeXYZ (ART 14/11/01)

c     Write out n atom labels and cartesian coordinates in standard
c     '.xyz' format. For viewing with eg. WebLab.

      SUBROUTINE writeXYZ(fileName,n,x,y,z,attype)
      IMPLICIT REAL*8(a-h,o-z)

c     Dummy arrays
       DIMENSION x(n),y(n),z(n)
         CHARACTER*2 attype(n)
      CHARACTER*60 fileName

c     Open the output file 
      OPEN(UNIT=100,FILE=fileName,FORM='FORMATTED',STATUS='UNKNOWN')

c     Write the headers
      WRITE(100,'(I3)') n
      WRITE(100,'(80A)') 'TITLE test for ed refinement model'
c     Write the atom lines
      DO i=1,n
      WRITE(100,1000) attype(i),x(i),y(i),z(i)
      END DO

c     Close the output file
      CLOSE(100)
      RETURN

 1000 FORMAT(A2,F9.4,F9.4,F9.4)
      END

	SUBROUTINE DihedralFromBeta(bondlen1,bondlen2,betaang,alpha1,
     + alpha2,dihedral)
      DOUBLEPRECISION term1,term2,term3,term4
	REAL*8 betaang,alpha1,alpha2,bondlen1,bondlen2,dihedral 
      term1=2*bondlen1*bondlen2*dcos(betaang)
      term2=2*bondlen1*bondlen2*dcos(alpha1)*dcos(alpha2)
      term3=dsqrt((bondlen1**2.)-(bondlen1**2.)*(dcos(alpha1)**2.))
      term4=dsqrt((bondlen2**2.)-(bondlen2**2.)*(dcos(alpha2)**2.))
	dihedral=dacos((term1-term2)/(2.*term3*term4))
	RETURN
      END      
