	PROGRAM TSIM_test
	IMPLICIT REAL*8(a-h,o-z)

	PARAMETER(nAtom=82,nIPar=100,nDist=1)

	DIMENSION x(nAtom),y(nAtom),z(nAtom)
	DIMENSION par(nIPar)
	DIMENSION uVal(nDist),rMult(nDist),ampDist(nDist)

c	parameter values par 1-14 taken as average from dominant conformer 
c	(All from MP2/AUGDZ calcs)
	par(1)=1.955	!from simultaneous eqn (ravg) 
	par(2)=0.239	!from simultaneous eqn
	par(3)=0.038	!from simultaneous eqn
	par(4)=1.101	!
	par(5)=110.36	!
	par(6)=115.31	!
	par(7)=109.71	!
	par(8)=107.12	!
	par(9)=104.02	!
	par(10)=109.47	!
	par(11)=-177.02	!
	par(12)=176.07	!
	par(13)=39.43	! dihedral chlorine branch 1 to 2 Si
	par(14)=158.95	! dihedral chlorine branch 2 to 1 Si
	par(15)=-72.85	! dihedral chlorine branch 3 to 1 Si
      par(16)=34.94	! dihedral chlorine branch 4 to 1 Si
	par(17)=-80.86	!
	par(18)=165.58	!

	CALL coord(nAtom,nIPar,nDist,x,y,z,par,uVal,rMult,ampDist)
	STOP
	END

c     Model for tetrakis(chlorodimethylsilyl)methane - multiconformer

	SUBROUTINE coord(nAtom,nIPar,nDist,x,y,z,par,uVal,rMult,ampDist)
	IMPLICIT REAL*8(a-h,o-z)

c	Dummy arrays
	DIMENSION x(nAtom),y(nAtom),z(nAtom)
	DIMENSION xa(nAtom),ya(nAtom),za(nAtom)
	DIMENSION par(nIPar),pp(50)
	DIMENSION uVal(nDist),rMult(nDist),ampDist(nDist)

c	Local arrays
	CHARACTER*2 attype(nAtom),attypea(nAtom)
	integer qq(nAtom)
	DIMENSION p(100)

c	Data statements
	attype = (/'C','H','H','H','C','H','H','H','Si','Cl','C','C','H',
     +'H','H','C','H','H','H','Si','Cl','C','H','H','H','C','H','H','H',
     +'Si','Cl','C','H','H','H','C','H','H','H','Si','Cl','C','H','H',
     +'H','C','H','H','H','Si','Cl','C','C','H','H','H','C','H','H','H',
     +'Si','Cl','C','H','H','H','C','H','H','H','Si','Cl','C','H','H',
     +'H','C','H','H','H','Si','Cl'/)

      qq=(/1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,
     +22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,
     +43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,61,62,63,
     +64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82/)
     
	pi=dacos(-1.0d0)
      rad=pi/180.0d0

c	Parameters for use in model(main parameter values from dominant 12A)

	rCSi1=par(1)-(par(2)/4)+((2*par(3))/3)		! central carbon to silicon
	rCSi2=par(1)-(par(2)/4)-(par(3)/3)			! methyl carbon to silicon
	rSiCl=par(1)+(3*par(2)/4)					! silicon chlorine distance
	rCH=par(4)				! carbon hydrogen distance
	aSiCH=par(5)*rad		! silicon methyl carbon to hydrogen angle
	aCSiC1=par(6)*rad		! central c si to methyl c angle
	aCSiC2=par(7)*rad		! methyl c si to methyl c angle
	aCSiCl1=par(8)*rad		! central c si cl
	aCSiCl2=par(9)*rad		! methyl c si cl
	aSiCSi=par(10)*rad		! si central c si
	dH1CSiCl=par(11)*rad	! end on view(SiC2H6Cl), d left methyl H to Cl
	dH2CSiCl=par(12)*rad	! end on view(SiC2H6Cl), d right methyl H to Cl
	dClSiCSi1=par(13)*rad	! Conf 1
      dClSiCSi2=par(14)*rad	! Conf 1
	dClSiCSi3=par(15)*rad	! Conf 1
	dClSiCSi4=par(16)*rad	! Conf 1
	dClSiCSi5=par(17)*rad	! Conf 2
	dClSiCSi6=par(18)*rad	! Conf 2

c	******************************
c	Start of model
c	First conformer Conformer (12)
c	******************************
c     Start of branch 1
      do i=1,41
	X(i)=0.0
	Y(i)=0.0
	Z(i)=0.0
	enddo
     
c     Define first SiMe2Cl group
c     Set C(1) at the origin
      X(1)=0.0
      Y(1)=0.0
      Z(1)=0.0

c     Set H(2) in x-y plane
      X(2)=rCH*dcos(aSiCH)
      Y(2)=rCH*dsin(aSiCH)
      Z(2)=0.0
      
c     generate Me group around C(1)
      Do i=1,2
      X(2+i)=X(2)
      Y(2+i)=Y(2)*dcos(120.*i*rad)-Z(2)*dsin(120.*i*rad)
      Z(2+i)=Y(2)*dsin(120.*i*rad)+Z(2)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(4+i)=X(i)
      Y(4+i)=Y(i)
      Z(4+i)=Z(i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=1,4
      A=Y(i)
      Y(i)=A*dcos(dH1CSiCl)-Z(i)*dsin(dH1CSiCl)
      Z(i)=A*dsin(dH1CSiCl)+Z(i)*dcos(dH1CSiCl)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=5,8
      A=Y(i)
      Y(i)=A*dcos(dH2CSiCl)-Z(i)*dsin(dH2CSiCl)
      Z(i)=A*dsin(dH2CSiCl)+Z(i)*dcos(dH2CSiCl)   
      enddo

c     Place Si(9) to origin
      X(9)=0.0
      Y(9)=0.0
      Z(9)=0.0
      
c     Move 1st Me group away from Si(9)
      Do i=1,4
      X(i)=X(i)-(rCSi2-0.004)
      enddo

c     Move 2nd Me group away from Si(9)
      Do i=5,8
      X(i)=X(i)-(rCSi2+0.001)
      enddo

c     Set Cl(10) in x-y plane
      X(10)=(rSiCl+0.009)*dcos(aCSiCl1-0.905*rad)
      Y(10)=(rSiCl+0.009)*dsin(aCSiCl1-0.905*rad)
      Z(10)=0.0
  
c     Bend methyl group 1 into position
      Do i=1,4
      A=X(i)
      X(i)=A*dcos(aCSiC1+1.090*rad+pi)-Y(i)*dsin(aCSiC1+1.090*rad+pi)
      Y(i)=A*dsin(aCSiC1+1.090*rad+pi)+Y(i)*dcos(aCSiC1+1.090*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=5,8
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.505*rad+pi)-Y(i)*dsin(aCSiC1-0.505*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.505*rad+pi)+Y(i)*dcos(aCSiC1-0.505*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(9)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta((rCSi2-0.004),(rCSi2+0.001),
     +(aCSiCl2+0.156*rad),aCSiCl1,aCSiC1,d1)
      call DihedralFromBeta((rCSi2-0.004),(rCSi2+0.001),
     +(aCSiCl2-0.614*rad),aCSiCl1,aCSiC1,d2)

c     Move methyl groups about x axis using dihedrals generated above
      do i=1,4
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=5,8
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo

c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=1,10
      X(i)=X(i)-(rCSi1+0.000)
      enddo

c	Create dihedral angle between Cl of branch 1 and branch 2.
	Do i=1,10
	A=Y(i)
	Y(i)=A*dcos(dClSiCSi1)-Z(i)*dsin(dClSiCSi1)
	Z(i)=-(A*dsin(dClSiCSi1)+Z(i)*dcos(dClSiCSi1))
	enddo



c     Start of branch 2
c     Define first SiMe2Cl group
c     Set C(12) at the origin
      X(12)=0.0
      Y(12)=0.0
      Z(12)=0.0

c     Set H(13) in x-y plane
      X(13)=rCH*dcos(aSiCH)
      Y(13)=rCH*dsin(aSiCH)
      Z(13)=0.0
      
c     generate Me group around C(12)
      Do i=1,2
      X(13+i)=X(13)
      Y(13+i)=Y(13)*dcos(120.*i*rad)-Z(13)*dsin(120.*i*rad)
      Z(13+i)=Y(13)*dsin(120.*i*rad)+Z(13)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(15+i)=X(11+i)
      Y(15+i)=Y(11+i)
      Z(15+i)=Z(11+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=1,4
      A=Y(11+i)
      Y(11+i)=A*dcos(dH1CSiCl)-Z(11+i)*dsin(dH1CSiCl)
      Z(11+i)=A*dsin(dH1CSiCl)+Z(11+i)*dcos(dH1CSiCl)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=16,19
      A=Y(i)
      Y(i)=A*dcos(dH2CSiCl)-Z(i)*dsin(dH2CSiCl)
      Z(i)=A*dsin(dH2CSiCl)+Z(i)*dcos(dH2CSiCl)   
      enddo

c     Place Si(20) to origin
      X(20)=0.0
      Y(20)=0.0
      Z(20)=0.0
      
c     Move 1st Me group away from Si(20)
      Do i=12,15
      X(i)=X(i)-(rCSi2+0.002)
      enddo

c     Move 2nd Me group away from Si(20)
      Do i=16,19
      X(i)=X(i)-(rCSi2-0.001)
      enddo

c     Set Cl(21) in x-y plane
      X(21)=(rSiCl+0.005)*dcos(aCSiCl1-0.687*rad)
      Y(21)=(rSiCl+0.005)*dsin(aCSiCl1-0.687*rad)
      Z(21)=0.0
  
c     Bend methyl group 1 into position
      Do i=12,15
      A=X(i)
      X(i)=A*dcos(aCSiC1+1.22*rad+pi)-Y(i)*dsin(aCSiC1+1.22*rad+pi)
      Y(i)=A*dsin(aCSiC1+1.22*rad+pi)+Y(i)*dcos(aCSiC1+1.22*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=16,19
      A=X(i)
      X(i)=A*dcos(aCSiC1+0.225*rad+pi)-Y(i)*dsin(aCSiC1+0.225*rad+pi)
      Y(i)=A*dsin(aCSiC1+0.225*rad+pi)+Y(i)*dcos(aCSiC1+0.225*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(20)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta((rCSi2+0.002),(rCSi2-0.001),
     +(aCSiCl2-0.964*rad),aCSiCl1,aCSiC1,d3)
      call DihedralFromBeta((rCSi2+0.002),(rCSi2-0.001),
     +(aCSiCl2+0.721*rad),aCSiCl1,aCSiC1,d4)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=12,15
      A=Y(i)
      Y(i)=A*dcos(d3)-Z(i)*dsin(d3)
      Z(i)=A*dsin(d3)+Z(i)*dcos(d3)
      enddo

      do i=16,19
      A=Y(i)
      Y(i)=A*dcos(-d4)-Z(i)*dsin(-d4)
      Z(i)=A*dsin(-d4)+Z(i)*dcos(-d4)
      enddo

c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=12,21
      X(i)=X(i)-(rCSi1-0.002)
      enddo

c	Create dihedral angle between Cl of branch 2 and branch 1.
	Do i=12,21
	A=Y(i)
	Y(i)=-(A*dcos(dClSiCSi2)-Z(i)*dsin(dClSiCSi2))
	Z(i)=A*dsin(dClSiCSi2)+Z(i)*dcos(dClSiCSi2)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=12,21
	A=X(i)
      X(i)=A*dcos(-aSiCSi-0.111*rad)-Y(i)*dsin(-aSiCSi-0.111*rad)
      Y(i)=A*dsin(-aSiCSi-0.111*rad)+Y(i)*dcos(-aSiCSi-0.111*rad)
	enddo



c     Start of Branch 3
c	Define first SiMe2Cl group
c	Set C(22) at the origin
      X(22)=0.0
      Y(22)=0.0
      Z(22)=0.0

c     Set H(23) in x-y plane
      X(23)=rCH*dcos(aSiCH)
      Y(23)=rCH*dsin(aSiCH)
      Z(23)=0.0
      
c     generate Me group around C(22)
      Do i=1,2
      X(23+i)=X(23)
      Y(23+i)=Y(23)*dcos(120.*i*rad)-Z(23)*dsin(120.*i*rad)
      Z(23+i)=Y(23)*dsin(120.*i*rad)+Z(23)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(25+i)=X(21+i)
      Y(25+i)=Y(21+i)
      Z(25+i)=Z(21+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=22,25
      A=Y(i)
      Y(i)=A*dcos(dH1CSiCl)-Z(i)*dsin(dH1CSiCl)
      Z(i)=A*dsin(dH1CSiCl)+Z(i)*dcos(dH1CSiCl)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=26,29
      A=Y(i)
      Y(i)=A*dcos(dH2CSiCl)-Z(i)*dsin(dH2CSiCl)
      Z(i)=A*dsin(dH2CSiCl)+Z(i)*dcos(dH2CSiCl)   
      enddo

c     Place Si(30) to origin
      X(30)=0.0
      Y(30)=0.0
      Z(30)=0.0
      
c     Move 1st Me group away from Si(30)
      Do i=22,25
      X(i)=X(i)-(rCSi2+0.001)
      enddo

c     Move 2nd Me group away from Si(30)
      Do i=26,29
      X(i)=X(i)-(rCSi2+0.001)
      enddo

c     Set Cl(31) in x-y plane
      X(31)=(rSiCl-0.014)*dcos(aCSiCl1+1.003*rad)
      Y(31)=(rSiCl-0.014)*dsin(aCSiCl1+1.003*rad)
      Z(31)=0.0
 
c     Bend methyl group 1 into position
      Do i=22,25
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.974*rad+pi)-Y(i)*dsin(aCSiC1-0.974*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.974*rad+pi)+Y(i)*dcos(aCSiC1-0.974*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=26,29
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.929*rad+pi)-Y(i)*dsin(aCSiC1-0.929*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.929*rad+pi)+Y(i)*dcos(aCSiC1-0.929*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(30)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta((rCSi2+0.001),(rCSi2+0.001),
     +(aCSiCl2+0.777*rad),aCSiCl1,aCSiC1,d5)
      call DihedralFromBeta((rCSi2+0.001),(rCSi2+0.001),
     +(aCSiCl2+1.274*rad),aCSiCl1,aCSiC1,d6)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=22,25
      A=Y(i)
      Y(i)=A*dcos(d5)-Z(i)*dsin(d5)
      Z(i)=A*dsin(d5)+Z(i)*dcos(d5)
      enddo

      do i=26,29
      A=Y(i)
      Y(i)=A*dcos(-d6)-Z(i)*dsin(-d6)
      Z(i)=A*dsin(-d6)+Z(i)*dcos(-d6)
      enddo


c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=22,31
      X(i)=X(i)-(rCSi1-0.003)
      enddo

c	Create dihedral angle between Cl of branch 3 and branch 1.
	Do i=22,31
	A=Y(i)
	Y(i)=-(A*dcos(dClSiCSi3)-Z(i)*dsin(dClSiCSi3))
	Z(i)=A*dsin(dClSiCSi3)+Z(i)*dcos(dClSiCSi3)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=22,31
	A=X(i)
      X(i)=A*dcos(-aSiCSi-0.629*rad)-Y(i)*dsin(-aSiCSi-0.629*rad)
      Y(i)=A*dsin(-aSiCSi-0.629*rad)+Y(i)*dcos(-aSiCSi-0.629*rad)
	enddo


c     Start of Branch 4
c     Define first SiMe2Cl group
c     Set C(32) at the origin
      X(32)=0.0
      Y(32)=0.0
      Z(32)=0.0

c     Set H(33) in x-y plane
      X(33)=rCH*dcos(aSiCH)
      Y(33)=rCH*dsin(aSiCH)
      Z(33)=0.0
      
c     generate Me group around C(32)
      Do i=1,2
      X(33+i)=X(33)
      Y(33+i)=Y(33)*dcos(120.*i*rad)-Z(33)*dsin(120.*i*rad)
      Z(33+i)=Y(33)*dsin(120.*i*rad)+Z(33)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(35+i)=X(31+i)
      Y(35+i)=Y(31+i)
      Z(35+i)=Z(31+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=32,35
      A=Y(i)
      Y(i)=A*dcos(dH1CSiCl)-Z(i)*dsin(dH1CSiCl)
      Z(i)=A*dsin(dH1CSiCl)+Z(i)*dcos(dH1CSiCl)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=36,39
      A=Y(i)
      Y(i)=A*dcos(dH2CSiCl)-Z(i)*dsin(dH2CSiCl)
      Z(i)=A*dsin(dH2CSiCl)+Z(i)*dcos(dH2CSiCl)   
      enddo

c     Place Si(40) to origin
      X(40)=0.0
      Y(40)=0.0
      Z(40)=0.0
      
c     Move 1st Me group away from Si(40)
      Do i=32,35
      X(i)=X(i)-(rCSi2-0.003)
      enddo

c     Move 2nd Me group away from Si(40)
      Do i=36,39
      X(i)=X(i)-(rCSi2+0.003)
      enddo
	
c     Set Cl(41) in x-y plane
      X(41)=(rSiCl-0.001)*dcos(aCSiCl1+0.590*rad)
      Y(41)=(rSiCl-0.001)*dsin(aCSiCl1+0.590*rad)
      Z(41)=0.0
  
c     Bend methyl group 1 into position
      Do i=32,35
      A=X(i)
      X(i)=A*dcos(aCSiC1+1.094*rad+pi)-Y(i)*dsin(aCSiC1+1.094*rad+pi)
      Y(i)=A*dsin(aCSiC1+1.094*rad+pi)+Y(i)*dcos(aCSiC1+1.094*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=36,39
      A=X(i)
      X(i)=A*dcos(aCSiC1-1.221*rad+pi)-Y(i)*dsin(aCSiC1-1.221*rad+pi)
      Y(i)=A*dsin(aCSiC1-1.221*rad+pi)+Y(i)*dcos(aCSiC1-1.221*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(30)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta((rCSi2-0.003),(rCSi2+0.003),
     +(aCSiCl2-1.147*rad),aCSiCl1,aCSiC1,d7)
      call DihedralFromBeta((rCSi2-0.003),(rCSi2+0.003),
     +(aCSiCl2-0.203*rad),aCSiCl1,aCSiC1,d8)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=32,35
      A=Y(i)
      Y(i)=A*dcos(d7)-Z(i)*dsin(d7)
      Z(i)=A*dsin(d7)+Z(i)*dcos(d7)
      enddo

      do i=36,39
      A=Y(i)
      Y(i)=A*dcos(-d8)-Z(i)*dsin(-d8)
      Z(i)=A*dsin(-d8)+Z(i)*dcos(-d8)
      enddo

c     Move origin to C(11)
      X(11)=0.0
      Y(11)=0.0
      Z(11)=0.0

      Do i=32,41
      X(i)=X(i)-(rCSi1+0.005)
      enddo

c	Create dihedral angle between Cl of branch 4 and branch 1.
	Do i=32,41
	A=Y(i)
	Y(i)=-(A*dcos(dClSiCSi4)-Z(i)*dsin(dClSiCSi4))
	Z(i)=A*dsin(dClSiCSi4)+Z(i)*dcos(dClSiCSi4)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=32,41
	A=X(i)
      X(i)=A*dcos(-aSiCSi+0.671*rad)-Y(i)*dsin(-aSiCSi+0.671*rad)
      Y(i)=A*dsin(-aSiCSi+0.671*rad)+Y(i)*dcos(-aSiCSi+0.671*rad)
	enddo


c     Put 3rd and 4th branch in position by rotation around C(11)
c     Generate dihedral angles to move branches (SuBroutine)
      call DihedralFromBeta(rCSi1,rCSi1,aSiCSi,aSiCSi,aSiCSi,d9)
      call DihedralFromBeta(rCSi1,rCSi1,aSiCSi,aSiCSi,aSiCSi,d10)

c     Move branches about x axis using dihedrals generated above
      do i=22,31
      A=Y(i)
      Y(i)=A*dcos(-d9)-Z(i)*dsin(-d9)
      Z(i)=A*dsin(-d9)+Z(i)*dcos(-d9)
      enddo

      do i=32,41
      A=Y(i)
      Y(i)=A*dcos(d10)-Z(i)*dsin(d10)
      Z(i)=A*dsin(d10)+Z(i)*dcos(d10)
      enddo

*************************************************************
c	do i=1,41
c	X(i)=X(i)+10
c	enddo
*************************************************************




c	*****************************************************************************************
c	Start of Conformer 2 (9A) 
c	******************************************************************************************


c     Set C(42) at the origin
      X(42)=0.0
      Y(42)=0.0
      Z(42)=0.0

c     Set H(43) in x-y plane
      X(43)=(rCH)*dcos(aSiCH)
      Y(43)=(rCH)*dsin(aSiCH)
      Z(43)=0.0
      
c     generate Me group around C(42)
      Do i=1,2
      X(43+i)=X(43)
      Y(43+i)=Y(43)*dcos(120.*i*rad)-Z(43)*dsin(120.*i*rad)
      Z(43+i)=Y(43)*dsin(120.*i*rad)+Z(43)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=1,4
      X(45+i)=X(41+i)
	Y(45+i)=Y(41+i)
      Z(45+i)=Z(41+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=42,45
      A=Y(i)
      Y(i)=A*dcos(dH1CSiCl)-Z(i)*dsin(dH1CSiCl)
      Z(i)=A*dsin(dH1CSiCl)+Z(i)*dcos(dH1CSiCl)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=46,49
      A=Y(i)
      Y(i)=A*dcos(dH2CSiCl)-Z(i)*dsin(dH2CSiCl)
      Z(i)=A*dsin(dH2CSiCl)+Z(i)*dcos(dH2CSiCl)   
      enddo


c     Place Si(50) to origin
      X(50)=0.0
      Y(50)=0.0
      Z(50)=0.0
      
c     Move 1st Me group away from Si(50)
      Do i=42,45
      X(i)=X(i)-rCSi2+0.006
      enddo

c     Move 2nd Me group away from Si(50)
      Do i=46,49
      X(i)=X(i)-rCSi2-0.003
      enddo

c     Set Cl(51) in x-y plane
      X(51)=(rSiCl-0.008)*dcos(aCSiCl1+0.87*rad)
      Y(51)=(rSiCl-0.008)*dsin(aCSiCl1+0.87*rad)
      Z(51)=0.0
  
c     Bend methyl group 1 into position
      Do i=42,45
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.68*rad+pi)-Y(i)*dsin(aCSiC1-0.68*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.68*rad+pi)+Y(i)*dcos(aCSiC1-0.68*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=46,49
      A=X(i)
      X(i)=A*dcos(aCSiC1+0.74*rad+pi)-Y(i)*dsin(aCSiC1+0.74*rad+pi)
      Y(i)=A*dsin(aCSiC1+0.74*rad+pi)+Y(i)*dcos(aCSiC1+0.74*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(50)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi2,rCSi2,aCSiCl2,aCSiCl1,aCSiC1,d1)
      call DihedralFromBeta(rCSi2,rCSi2,aCSiCl2,aCSiCl1,aCSiC1,d2)

c     Move methyl groups about x axis using dihedrals generated above
      do i=42,45
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=46,49
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo
c
c     Move origin to C(52)
      X(52)=0.0
      Y(52)=0.0
      Z(52)=0.0

      Do i=42,51
      X(i)=X(i)-rCSi1+0.006
      enddo

c	Create dihedral angle between Cl of branch 1 and branch 3.
	Do i=42,51
	A=Y(i)
	Y(i)=A*dcos(dClSiCSi5)-Z(i)*dsin(dClSiCSi5)
	Z(i)=-(A*dsin(dClSiCSi5)+Z(i)*dcos(dClSiCSi5))
	enddo





c     Start of Branch 3
c	Define first SiMe2Cl group
c	Set C(63) at the origin
      X(63)=0.0
      Y(63)=0.0
      Z(63)=0.0

c     Set H(64) in x-y plane
      X(64)=rCH*dcos(aSiCH)
      Y(64)=rCH*dsin(aSiCH)
      Z(64)=0.0
      
c     generate Me group around C(63)
      Do i=1,2
      X(64+i)=X(64)
      Y(64+i)=Y(64)*dcos(120.*i*rad)-Z(64)*dsin(120.*i*rad)
      Z(64+i)=Y(64)*dsin(120.*i*rad)+Z(64)*dcos(120.*i*rad)
      enddo

c     Generate 2nd Me group in same position as 1st
      Do i=42,45
      X(25+i)=X(21+i)
	Y(25+i)=Y(21+i)
      Z(25+i)=Z(21+i)
      enddo

c     now twist 1st Me group (about x-axis)
      Do i=63,66
      A=Y(i)
      Y(i)=A*dcos(dH1CSiCl)-Z(i)*dsin(dH1CSiCl)
      Z(i)=A*dsin(dH1CSiCl)+Z(i)*dcos(dH1CSiCl)   
      enddo

c     now twist 2nd Me group (about x-axis)
      Do i=67,70
      A=Y(i)
      Y(i)=A*dcos(dH2CSiCl)-Z(i)*dsin(dH2CSiCl)
      Z(i)=A*dsin(dH2CSiCl)+Z(i)*dcos(dH2CSiCl)   
      enddo

c     Place Si(71) to origin
      X(71)=0.0
      Y(71)=0.0
      Z(71)=0.0
      
c     Move 1st Me group away from Si(71)
      Do i=63,66
      X(i)=X(i)-rCSi2+0.000
      enddo

c     Move 2nd Me group away from Si(71)
      Do i=67,70
      X(i)=X(i)-rCSi2+0.000
      enddo

c     Set Cl(72) in x-y plane
      X(72)=(rSiCl-0.000)*dcos(aCSiCl1+0.57*rad)
      Y(72)=(rSiCl-0.000)*dsin(aCSiCl1+0.57*rad)
      Z(72)=0.0
 
c     Bend methyl group 1 into position
      Do i=63,66
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.28*rad+pi)-Y(i)*dsin(aCSiC1-0.28*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.28*rad+pi)+Y(i)*dcos(aCSiC1-0.28*rad+pi)
      enddo

c     Bend methyl group 2 into position
      Do i=67,70
      A=X(i)
      X(i)=A*dcos(aCSiC1-0.71*rad+pi)-Y(i)*dsin(aCSiC1-0.71*rad+pi)
      Y(i)=A*dsin(aCSiC1-0.71*rad+pi)+Y(i)*dcos(aCSiC1-0.71*rad+pi)
      enddo

c     Put 1st and 2nd Me in position by rotation around Si(71)
c     Generate dihedral angles to move methyl groups (SuBroutine)
      call DihedralFromBeta(rCSi2,rCSi2,aCSiCl2,aCSiCl1,aCSiC1,d1)
      call DihedralFromBeta(rCSi2,rCSi2,aCSiCl2,aCSiCl1,aCSiC1,d2)
     
c     Move methyl groups about x axis using dihedrals generated above
      do i=63,66
      A=Y(i)
      Y(i)=A*dcos(d1)-Z(i)*dsin(d1)
      Z(i)=A*dsin(d1)+Z(i)*dcos(d1)
      enddo

      do i=67,70
      A=Y(i)
      Y(i)=A*dcos(-d2)-Z(i)*dsin(-d2)
      Z(i)=A*dsin(-d2)+Z(i)*dcos(-d2)
      enddo


c     Move origin to C(52)
      X(52)=0.0
      Y(52)=0.0
      Z(52)=0.0

      Do i=63,72
      X(i)=X(i)-rCSi1-0.005
      enddo

c	Create dihedral angle between Cl of branch 3 and branch 1.
	Do i=63,72
	A=Y(i)
	Y(i)=-(A*dcos(dClSiCSi6)-Z(i)*dsin(dClSiCSi6))
	Z(i)=A*dsin(dClSiCSi6)+Z(i)*dcos(dClSiCSi6)
	enddo

c	Move away from branch 1 by aSiCSi1
	do i=63,72
	A=X(i)
      X(i)=A*dcos(-aSiCSi+2.19*rad)-Y(i)*dsin(-aSiCSi+2.19*rad)
      Y(i)=A*dsin(-aSiCSi+2.19*rad)+Y(i)*dcos(-aSiCSi+2.19*rad)
	enddo

c	rotate around z by (angle between branch 1 and 3)/2
	do i=42,82
	A=X(i)
	X(i)=A*dcos((aSiCSi-2.19*rad)/2)-Y(i)*dsin((aSiCSi-2.19*rad)/2)
	Y(i)=A*dsin((aSiCSi-2.19*rad)/2)+Y(i)*dcos((aSiCSi-2.19*rad)/2)
	enddo

c	Place atoms 53-62 on 42-51 
	do i=53,62
	X(i)=X(i-11)
	Y(i)=Y(i-11)
	Z(i)=Z(i-11)
	enddo

c	 73-82 on 63-72
	Do i=73,82
	X(i)=X(i-10)
	Y(i)=Y(i-10)
	Z(i)=Z(i-10)
	enddo

c	Rotate about x-axis by (dSiCXSi)
	do i=53,62
	A=Y(i)
	Y(i)=A*dcos(pi/2)-Z(i)*dsin(pi/2)
	Z(i)=A*dsin(pi/2)+Z(i)*dcos(pi/2)
	enddo

c	Rotate about x-axis by (dSiCXSi)
	do i=73,82
	A=Y(i)
	Y(i)=A*dcos(pi/2)-Z(i)*dsin(pi/2)
	Z(i)=A*dsin(pi/2)+Z(i)*dcos(pi/2)
	enddo


c	Rotate branch 2 and 4 about y axis by pi
	do i=53,62
	A=X(i)
	X(i)=A*dcos(pi)+Z(i)*dsin(pi)
	Z(i)=-A*dsin(pi)+Z(i)*dcos(pi)
	enddo

	do i=73,82
	A=X(i)
	X(i)=A*dcos(pi)+Z(i)*dsin(pi)
	Z(i)=-A*dsin(pi)+Z(i)*dcos(pi)
	enddo

c***********************************************************************************************
c	do i=73,82
c	X(i)=X(i)+10
c	enddo
c
c	do i=53,62
c	X(i)=X(i)+10
c	enddo
c
c
c	do i=1,41
c	X(i)=X(i)+10
c	enddo
c
***************************************************************************************************






c	Make numbering same as ab initio
	Do i=1,nAtom
	XA(qq(i))=X(i)
	YA(qq(i))=Y(i)
	ZA(qq(i))=Z(i)
	attypea(qq(i))=attype(i)
	enddo

	Do i=1,nAtom
	X(i)=XA(i)
	Y(i)=YA(i)
	Z(i)=ZA(i)
	attype(i)=attypea(i)
	enddo

c     Write the co-ordinates
	CALL writeXYZ('coord.xyz',nAtom,x,y,z,attype)

	RETURN
	END

c     Subroutine writeXYZ (ART 14/11/01)

c     Write out n atom labels and cartesian coordinates in standard
c     '.xyz' format. For viewing with eg. WebLab.

      SUBROUTINE writeXYZ(fileName,n,x,y,z,attype)
      IMPLICIT REAL*8(a-h,o-z)

c     Dummy arrays
       DIMENSION x(n),y(n),z(n)
         CHARACTER*2 attype(n)
      CHARACTER*60 fileName

c     Open the output file 
      OPEN(UNIT=100,FILE=fileName,FORM='FORMATTED',STATUS='UNKNOWN')

c     Write the headers
      WRITE(100,'(I3)') n
      WRITE(100,'(80A)') 'TITLE test for ed refinement model'
c     Write the atom lines
      DO i=1,n
      WRITE(100,1000) attype(i),x(i),y(i),z(i)
      END DO

c     Close the output file
      CLOSE(100)
      RETURN

 1000 FORMAT(A2,F9.4,F9.4,F9.4)
      END

	SUBROUTINE DihedralFromBeta(bondlen1,bondlen2,betaang,alpha1,
     + alpha2,dihedral)
      DOUBLEPRECISION term1,term2,term3,term4
	REAL*8 betaang,alpha1,alpha2,bondlen1,bondlen2,dihedral 
      term1=2*bondlen1*bondlen2*dcos(betaang)
      term2=2*bondlen1*bondlen2*dcos(alpha1)*dcos(alpha2)
      term3=dsqrt((bondlen1**2.)-(bondlen1**2.)*(dcos(alpha1)**2.))
      term4=dsqrt((bondlen2**2.)-(bondlen2**2.)*(dcos(alpha2)**2.))
	dihedral=dacos((term1-term2)/(2.*term3*term4))
	RETURN
      END      
